@@ -1,8 +1,6 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 7                                                        |
-   +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2019 The PHP Group                                |
+   | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -28,6 +26,8 @@
 #include "main/php_output.h"
 #include "php_open_temporary_file.h"
 
+#include "arginfo.h"
+
 /* just in case the config check doesn't enable mbstring automatically */
 #if !HAVE_MBSTRING
 #error The mailparse extension requires the mbstring extension!
@@ -54,41 +54,40 @@ static size_t mailparse_do_uudecode(php_stream *instream, php_stream *outstream)
 
 static int le_mime_part;
 
-
 static zend_function_entry mimemessage_methods[] = {
-	PHP_NAMED_FE(mimemessage,			PHP_FN(mailparse_mimemessage),					NULL)
-	PHP_NAMED_FE(get_child,				PHP_FN(mailparse_mimemessage_get_child),		NULL)
-	PHP_NAMED_FE(get_child_count,		PHP_FN(mailparse_mimemessage_get_child_count),	NULL)
-	PHP_NAMED_FE(get_parent,			PHP_FN(mailparse_mimemessage_get_parent),		NULL)
-	PHP_NAMED_FE(extract_headers,		PHP_FN(mailparse_mimemessage_extract_headers),	NULL)
-	PHP_NAMED_FE(extract_body,			PHP_FN(mailparse_mimemessage_extract_body),		NULL)
-	PHP_NAMED_FE(enum_uue,				PHP_FN(mailparse_mimemessage_enum_uue),			NULL)
-	PHP_NAMED_FE(extract_uue,			PHP_FN(mailparse_mimemessage_extract_uue),		NULL)
-	PHP_NAMED_FE(remove,				PHP_FN(mailparse_mimemessage_remove),			NULL)
-	PHP_NAMED_FE(add_child,				PHP_FN(mailparse_mimemessage_add_child),		NULL)
+	PHP_ME(mimemessage, __construct,     arginfo_mailparse_mimemessage_construct,       ZEND_ACC_PUBLIC|ZEND_ACC_CTOR)
+	PHP_ME(mimemessage, get_child,       arginfo_mailparse_mimemessage_get_child,       ZEND_ACC_PUBLIC)
+	PHP_ME(mimemessage, get_child_count, arginfo_mailparse_mimemessage_get_child_count, ZEND_ACC_PUBLIC)
+	PHP_ME(mimemessage, get_parent,      arginfo_mailparse_mimemessage_get_parent,      ZEND_ACC_PUBLIC)
+	PHP_ME(mimemessage, extract_headers, arginfo_mailparse_mimemessage_extract_headers, ZEND_ACC_PUBLIC)
+	PHP_ME(mimemessage, extract_body,    arginfo_mailparse_mimemessage_extract_body,    ZEND_ACC_PUBLIC)
+	PHP_ME(mimemessage, enum_uue,        arginfo_mailparse_mimemessage_enum_uue,        ZEND_ACC_PUBLIC)
+	PHP_ME(mimemessage, extract_uue,     arginfo_mailparse_mimemessage_extract_uue,     ZEND_ACC_PUBLIC)
+	PHP_ME(mimemessage, remove,          arginfo_mailparse_mimemessage_remove,          ZEND_ACC_PUBLIC)
+	PHP_ME(mimemessage, add_child,       arginfo_mailparse_mimemessage_add_child,       ZEND_ACC_PUBLIC)
 	{NULL, NULL, NULL}
 };
 
 static zend_class_entry *mimemsg_class_entry;
 
 zend_function_entry mailparse_functions[] = {
-	PHP_FE(mailparse_msg_parse_file,			NULL)
-	PHP_FE(mailparse_msg_get_part,				NULL)
-	PHP_FE(mailparse_msg_get_structure,			NULL)
-	PHP_FE(mailparse_msg_get_part_data,			NULL)
-	PHP_FE(mailparse_msg_extract_part,			NULL)
-	PHP_FE(mailparse_msg_extract_part_file,		NULL)
-	PHP_FE(mailparse_msg_extract_whole_part_file,		NULL)
+	PHP_FE(mailparse_msg_parse_file,				arginfo_mailparse_msg_parse_file)
+	PHP_FE(mailparse_msg_get_part,					arginfo_mailparse_msg_get_part)
+	PHP_FE(mailparse_msg_get_structure,				arginfo_mailparse_msg_get_structure)
+	PHP_FE(mailparse_msg_get_part_data,				arginfo_mailparse_msg_get_part_data)
+	PHP_FE(mailparse_msg_extract_part,				arginfo_mailparse_msg_extract_part)
+	PHP_FE(mailparse_msg_extract_part_file,			arginfo_mailparse_msg_extract_part_file)
+	PHP_FE(mailparse_msg_extract_whole_part_file,	arginfo_mailparse_msg_extract_whole_part_file)
 
-	PHP_FE(mailparse_msg_create,				NULL)
-	PHP_FE(mailparse_msg_free,				NULL)
-	PHP_FE(mailparse_msg_parse,				NULL)
-	PHP_FE(mailparse_rfc822_parse_addresses,		NULL)
-	PHP_FE(mailparse_determine_best_xfer_encoding, NULL)
-	PHP_FE(mailparse_stream_encode,						NULL)
-	PHP_FE(mailparse_uudecode_all,					NULL)
+	PHP_FE(mailparse_msg_create,					arginfo_mailparse_msg_create)
+	PHP_FE(mailparse_msg_free,						arginfo_mailparse_msg_free)
+	PHP_FE(mailparse_msg_parse,						arginfo_mailparse_msg_parse)
+	PHP_FE(mailparse_rfc822_parse_addresses,		arginfo_mailparse_rfc822_parse_addresses)
+	PHP_FE(mailparse_determine_best_xfer_encoding, 	arginfo_mailparse_determine_best_xfer_encoding)
+	PHP_FE(mailparse_stream_encode,					arginfo_mailparse_stream_encode)
+	PHP_FE(mailparse_uudecode_all,					arginfo_mailparse_uudecode_all)
 
-	PHP_FE(mailparse_test,	NULL)
+	PHP_FE(mailparse_test,							arginfo_mailparse_test)
 
 	PHP_FE_END
 };
@@ -230,7 +229,7 @@ static int mailparse_mimemessage_export(php_mimepart *part, zval *object)
 	return SUCCESS;
 }
 
-PHP_FUNCTION(mailparse_mimemessage)
+PHP_METHOD(mimemessage, __construct)
 {
 	zval *object = getThis();
 	php_mimepart *part;
@@ -304,7 +303,7 @@ PHP_FUNCTION(mailparse_mimemessage)
 	mailparse_mimemessage_populate(part, object);
 }
 
-PHP_FUNCTION(mailparse_mimemessage_remove)
+PHP_METHOD(mimemessage, remove)
 {
 	php_mimepart *part;
 
@@ -315,7 +314,7 @@ PHP_FUNCTION(mailparse_mimemessage_remove)
 	php_mimepart_remove_from_parent(part);
 }
 
-PHP_FUNCTION(mailparse_mimemessage_add_child)
+PHP_METHOD(mimemessage, add_child)
 {
 	php_mimepart *part;
 
@@ -327,7 +326,7 @@ PHP_FUNCTION(mailparse_mimemessage_add_child)
 }
 
 
-PHP_FUNCTION(mailparse_mimemessage_get_child_count)
+PHP_METHOD(mimemessage, get_child_count)
 {
 	php_mimepart *part;
 
@@ -338,7 +337,7 @@ PHP_FUNCTION(mailparse_mimemessage_get_child_count)
 	RETURN_LONG(zend_hash_num_elements(&part->children));
 }
 
-PHP_FUNCTION(mailparse_mimemessage_get_parent)
+PHP_METHOD(mimemessage, get_parent)
 {
 	php_mimepart *part;
 
@@ -351,7 +350,7 @@ PHP_FUNCTION(mailparse_mimemessage_get_parent)
 	}
 }
 
-PHP_FUNCTION(mailparse_mimemessage_get_child)
+PHP_METHOD(mimemessage, get_child)
 {
 	php_mimepart *part, *foundpart;
 	zval *item_to_find;
@@ -451,17 +450,17 @@ cleanup:
 
 }
 
-PHP_FUNCTION(mailparse_mimemessage_extract_headers)
+PHP_METHOD(mimemessage, extract_headers)
 {
 	mailparse_mimemessage_extract(MAILPARSE_DECODE_NOBODY, INTERNAL_FUNCTION_PARAM_PASSTHRU);
 }
 
-PHP_FUNCTION(mailparse_mimemessage_extract_body)
+PHP_METHOD(mimemessage, extract_body)
 {
 	mailparse_mimemessage_extract(MAILPARSE_DECODE_NOHEADERS | MAILPARSE_DECODE_8BIT, INTERNAL_FUNCTION_PARAM_PASSTHRU);
 }
 
-PHP_FUNCTION(mailparse_mimemessage_extract_uue)
+PHP_METHOD(mimemessage, extract_uue)
 {
 	php_mimepart *part;
 	zval *zarg = NULL;
@@ -477,11 +476,13 @@ PHP_FUNCTION(mailparse_mimemessage_extract_uue)
 
 	RETVAL_NULL();
 
-	if (part == NULL)
+	if (part == NULL) {
 		return;
+	}
 
-	if (FAILURE == zend_parse_parameters(ZEND_NUM_ARGS(), "l|lz!", &index, &mode, &zarg))
+	if (FAILURE == zend_parse_parameters(ZEND_NUM_ARGS(), "l|lz", &index, &mode, &zarg)) {
 		return;
+	}
 
 	switch(mode) {
 		case MAILPARSE_EXTRACT_STREAM:
@@ -564,7 +565,7 @@ cleanup:
 
 }
 
-PHP_FUNCTION(mailparse_mimemessage_enum_uue)
+PHP_METHOD(mimemessage, enum_uue)
 {
 	php_stream *instream;
 	php_mimepart *part;
@@ -658,7 +659,6 @@ PHP_MINFO_FUNCTION(mailparse)
 	php_info_print_table_start();
 	php_info_print_table_header(2, "mailparse support", "enabled");
 	php_info_print_table_row(2, "Extension Version", PHP_MAILPARSE_VERSION);
-	php_info_print_table_row(2, "Revision", "$Revision$");
 	php_info_print_table_end();
 
 	DISPLAY_INI_ENTRIES();
@@ -1379,7 +1379,7 @@ static void add_attr_header_to_zval(char *valuelabel, char *attrprefix, zval *re
 	HashPosition pos;
 	zval *val;
 	char *newkey;
-	ulong num_index;
+	zend_ulong num_index;
 	zend_string *str_key;
 
 	zend_hash_internal_pointer_reset_ex(Z_ARRVAL_P(&attr->attributes), &pos);
@@ -1390,7 +1390,7 @@ static void add_attr_header_to_zval(char *valuelabel, char *attrprefix, zval *re
     if (str_key) {
       spprintf(&newkey, 0, "%s%s", attrprefix, ZSTR_VAL(str_key));
     } else {
-      spprintf(&newkey, 0, "%s%lu", attrprefix, num_index);
+      spprintf(&newkey, 0, "%s" ZEND_ULONG_FMT, attrprefix, num_index);
     }
     add_assoc_string(return_value, newkey, Z_STRVAL_P(val));
     efree(newkey);
